@@ -5,7 +5,7 @@ if django.VERSION[:2] >= (1, 3):
         'default': {
             'ENGINE': 'django.db.backends.sqlite3',
             'NAME': ':memory:',
-        }
+        },
     }
 else:
     DATABASE_ENGINE = 'sqlite3'
@@ -13,5 +13,4 @@ else:
 SECRET_KEY = '_'
 ROOT_URLCONF = 'test_app.urls'
 INSTALLED_APPS = ('django_nose', 'django_geoip', 'test_app')
-TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
-NOSE_ARGS = ["-a!system"]
\ No newline at end of file
+TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
\ No newline at end of file
